pub struct ReferenceValues { /* private fields */ }Expand description
Values used in CieCam forward and backward transformations, only dependent on the view conditions and the reference white. For a set of colors, viewed under the same conditions, these have to be calculated only once.