pub struct SpectralLocus { /* private fields */ }Expand description
Represents the spectral locus, which includes:
- An observer for spectral data.
- A vector of tuples where each tuple contains:
- A wavelength (usize).
- A chromaticity coordinate ([f64; 2]).
Implementations
Sourceimpl SpectralLocus
impl SpectralLocus
pub fn new(observer: Observer) -> Self
pub fn contains(&self, point: [f64; 2]) -> bool
pub fn observer(&self) -> Observer
Sourcepub fn iter_range_with_slope<'a>(
&'a self,
range: impl RangeBounds<usize>,
step: usize,
) -> SpectralLocusSlopeIterator<'a>
pub fn iter_range_with_slope<'a>( &'a self, range: impl RangeBounds<usize>, step: usize, ) -> SpectralLocusSlopeIterator<'a>
Iterate over the spectral locus points over a given wavelength range and step size producing the spectral locus coordinates (f64, f64) and slope angles f64 in radians. The slope is calculated using a quadratic curve fit for interior points, and a simple difference for the endpoints.
This iterator is useful for applications that require not only the locus points, but also the direction of the locus at each point, for example when plotting tick marks along the spectral locus in plots, to find its boundaries.
Item
Each iteration yields a tuple:
((f64, f64), f64)- The chromaticity coordinate (x, y) of the locus point.
- The slope angle (in radians) at that point.
pub fn polygon(&self) -> &Polygon